package org.example.webtests.steps;

import com.microsoft.playwright.Page;
import io.cucumber.java.Before;
import io.cucumber.java.After;
import io.cucumber.java.en.Given;
import io.cucumber.java.en.Then;
import io.cucumber.java.en.When;
import org.example.pages.Home;
import org.example.pages.Login;
import org.example.utils.TestContext;
import org.junit.Assert;

public class LoginSteps {
    Login login;
    Home home;
    TestContext testContext = new TestContext("webkit", true);
    Page page = testContext.page;

    @Before
    public void setUp() {
        home = new Home(page);
        login = new Login(page);
    }

    @Given("User has a functional browser")
    public void userHasAFunctionalBrowser() {
        Assert.assertEquals("webkit", testContext.browser.browserType().name());
    }

    @Then("User can see the SwagLabs login page")
    public void userCanSeeTheSwagLabsLoginPage() {
        Assert.assertTrue(login.usernameField().isVisible() && login.usernameField().isEditable());
        Assert.assertTrue(login.passwordField().isVisible() && login.passwordField().isEditable());
    }

    @Given("User navigates to the Swaglabs site")
    public void userNavigatesToSwagLabs() {
        page.navigate("https://www.saucedemo.com/");
        Assert.assertEquals(login.title(), "Swag Labs");
    }

    @Given("Unauthenticated user is at the SwagLabs login page")
    public void verifyLoginPage() {
        Assert.assertTrue(login.usernameField().isVisible() && login.usernameField().isEditable());
        Assert.assertTrue(login.passwordField().isVisible() && login.passwordField().isEditable());
    }
    //Login into the application
    @When("User logs in using username {string} and password {string}")
    public void loginIntoTheApplication(String username,String password ) {
        login.loginIntoApplication(username, password);
        Assert.assertEquals("hello","hello");
    }
    //Verify product name after login
    @Then("User can see product {string}")
    public void verifyProductsName(String productname) {
        String productName = home.getProductName();
        Assert.assertEquals(productName, productname);
    }

    //Logout from application
    @After
    public void logoutFromApplication() {
        login.logoutApplication();
    }
}
